slepc-3.18.0 2022-10-01
Report Typos and Errors

# LMEReset

Resets the LME context to the initial state (prior to setup) and destroys any allocated Vecs and Mats.

### Synopsis

    #include "slepclme.h"
    PetscErrorCode LMEReset(LME lme)

Collective on lme

### Input Parameter

| lme | - linear matrix equation context obtained from LMECreate()

### See Also

LMEDestroy()

### Level

advanced

### Location

src/lme/interface/lmebasic.c
Index of all LME routines
Table of Contents for all manual pages
Index of all manual pages